################################################################################
################### Functions for loading scorecard data  ######################
################################################################################


##### Load libraries ######

library(ncdf4) ## to load netCDF files
library(formattable) ## to plot horizontal color bars
library(kableExtra) ## to print data in formatted tables
library(stringr) ## for manipulating capitals in the figure title
library(s2dv) ## for function ColorBar() ## previously s2dverification
library(abind) ## for function abind()
library(data.table) ## for function %like%
library(ClimProjDiags) ## for WeightedMean function
library(yaml) ## to read yaml files


##### Colour scale function #####

# For if certain variables require different colour palette
# 
# initialfunction_colorscale <- function(var.name) {
#   # inverse color scale: 
#   #   usually: inverse.scale = FALSE -> blue (min values) to red (max values) 
#   #   special variables: inverse.scale = TRUE -> red (min values) to blue (max values)
#   inverse.scale = FALSE
#   if(var.name == ""){ #Total precipitation #finally not used: all variables same palette
#     inverse.scale = TRUE
#   }
#   
#   return (inverse.scale)
# }


##### Adjust bias scale function #####
# 
# initialfunction_roundbias <- function(var.name, plevel){
#   ## round the scores:
#   n.dec <- 2
#   if(var.name == "Geopotential" && plevel == 50) n.dec = 0
#   if(var.name == "Geopotential" && plevel == 200) n.dec = 0
#   if(var.name == "Geopotential" && plevel == 500) n.dec = 0
#   if(var.name == "Geopotential" && plevel == 850) n.dec = 0
#   
#   if(var.name == "Specific humidity" && plevel == 500) n.dec = 0
#   if(var.name == "Specific humidity" && plevel == 850) n.dec = 0
#   
#   if(var.name == "Snow depth") n.dec = 1
#   if(var.name == "Mean sea level pressure") n.dec = 0
#   if(var.name == "Surface sensible heat flux") n.dec = 1
#   if(var.name == "Surface solar radiation downwards") n.dec = 1
#   if(var.name == "Snow density") n.dec = 1 
#   
#   return (n.dec) #, n.dec.leg)
# }
# 

##### Define regions #####

# initialfunction_regionnames_and_borders <- function() {
#   #define region names
#   region.names <- c("Tropics", "Extra-tropical NH", "Extra-tropical SH") 
#   
#   ## create full region names to show in the figures:
#   region.names.figure_by_region <- c("Tropics (30°S-30°N)", "Extra-tropical NH (30°N-90°N)", "Extra-tropical SH (30°S-90°S)")
#   region.names.figure <- c("(30°S-30°N)", "(30°N-90°N)", "(30°S-90°S)")
#   
#   ## set region borders:
#   lat.min <- c(-30, 30, -90)
#   lat.max <- c(30, 90, -30)
#   lon.min <- c("", "", "")
#   lon.max <- c("", "", "")
#   
#   names <- cbind(region.names, region.names.figure, lat.min, lat.max, lon.min, lon.max, region.names.figure_by_region)
#   
#   return (names)
# }
# 


##### Find position of lat and lon for defined regions ######

# initialfunction_position_latlon <- function(position, latlon_netcdf){
#   closest_value_in_vector <- sapply(position, function(position, latlon_netcdf) {latlon_netcdf[which.min(abs(position - latlon_netcdf))]}, latlon_netcdf)
#   find_closest_value_position <- which(latlon_netcdf == closest_value_in_vector)
#   return(find_closest_value_position)
# }

##### Image path to save for simple scorecard  ######

save_scorecard_single <- function(system, reference, var, start.year, end.year, scorecard_type){
  
  period <- paste0(start.year, "-", end.year)
   
  # if(plevel==""){
  #   scorecard_save_path <- paste0(fileout, "/", system.filename,
  #                                 "/scorecard-", scorecard_type, "_", system.filename, "_", reference.filename, "_",
  #                                 var.filename, "_", hindcasts.filename, ".png")
  # }else{
    scorecard_save_path <- paste0(fileout, # "/", system,
                                  "/scorecard-", scorecard_type, "_", system, "_", reference, "_",
                                  var, "_", period, ".png")
    
  
  return(scorecard_save_path)
  
}


##### Image path to save for multi scorecard ######

save_scorecard_multi <- function(model, eval.name, var, start.year, end.year, scorecard_type, region){
  
  period <- paste0(start.year, "-", end.year)

  scorecard_save_path <- paste0(fileout, # "/", system,
                                "/scorecard-", scorecard_type, "_multi-", tolower(model), "_", eval.name, "_",
                                var, "_", period, "_", region, ".png")
  
  
  return(scorecard_save_path)
  
}

