#' Scorecards spatially transform calculated means
#' 
#'@description Scorecards function to spatially transform the layout of the 
#'calculated metric means, to show 'Target Month' instead of 'Start Date'.
#'
#'@param data_to_transform is an array of spatially aggregated data containing 
#'  the following dimensions; system, reference, metric, region, sdate, ftime.
#'@param sdate_dim is a character name referring to the dimension of start date 
#'  in the array aggregated_metrics
#'@param ftime_dim is a character name referring to the dimension of forecast 
#'  time in the array aggregated_metrics
#'  
#'@example 
#'transformed_data <- SC_transform_data(data_to_transform = aggregated_metrics,
#'                                      sdate_dim = 'sdate',
#'                                      ftime_dim = 'time')


SC_transform_data<- function(data_to_transform,
                             sdate_dim,
                             ftime_dim) {
  
      ## Obtain maximum start date value
      max_sdates <- dim(aggregated_metrics)[sdate_dim]
      
      transformed <- array(dim = dim(aggregated_metrics))
      transformed[,,,1,,] <- aggregated_metrics[,,,1,,] ## position of forecast month, TO DO: make position flexible!!
        ## Loop over forecast time      
        for(i in 2:dim(aggregated_metrics)[ftime_dim]) {
              transformed[,,,i,,] <- Subset(aggregated_metrics[,,,i,,], along = sdate_dim, 
                                        indices = c((max_sdates-i+2):max_sdates, 1:(max_sdates-i+1)), drop = FALSE)
        } ## close loop on i
  
 return(transformed)


} ## close function
