#' Function to calculate color bar breaks for bias metric
#' 
#'@description Scorecards function to calculate the breaks of the metric 
#'  'mean_bias' for the legend color bar.
#'  
#'@param data an array with Mean Bias values 
#'
#'@example 
#' breaks_bias <- SC_breaks(Subset(data, along = 'metric', 
#'                          indices = which(metrics == 'mean_bias')))
#'                          

SC_breaks <- function(data){
  
  bias.max <- max(abs(data), na.rm = TRUE)
  bias.minmax_max <- quantile(data, 0.98, na.rm = TRUE)
  bias.minmax_min <- quantile(data, 0.02, na.rm = TRUE)
  bias.max <- max(abs(bias.minmax_min), abs(bias.minmax_max))
  
  bias.int <- bias.max * c(-1, -0.8, -0.6, -0.4, -0.2, 0, 0.2, 0.4, 0.6, 0.8, 1) ## one point more than the colors below (the intervals)
  
  ## round to 2 significance figures
  bias.int <- signif(bias.int, digits = 2)
  
  return(bias.int)
}
