#'Function to create the legends for the scorecard tables
#' 
#'@description Scorecards function to create the color bar legends for the 
#'  required metrics and paste them below the scorecard table

SC_legend <- function(table.html,
                      metrics,
                      metric.breaks,
                      palette,
                      colorunder,
                      colorup,
                      fileout){


  ## Create color bar legends for each necessary metric
  if('mean_bias' %in% metrics){
    png(filename= paste0(fileout, "/scorecard_legend_mean_bias.png"), width=515, height=40) ## 455
    ColorBar(brks = metric.breaks[['mean_bias']], cols = palette, vertical = FALSE, triangle_ends_scale = 1, col_inf = colorunder, col_sup = colorsup) 
    dev.off()
  }
  if('enscorr' %in% metrics){
    png(filename= paste0(fileout, "/scorecard_legend_enscorr.png"), width=520, height=40)
    ColorBar(brks = metric.breaks[['enscorr']], cols = palette, vertical = FALSE, triangle_ends_scale = 0, col_inf = colorunder)
    dev.off()
  }
  if('rpss' %in% metrics){
    png(filename= paste0(fileout, "/scorecard_legend_rpss.png"), width=515, height=40)
    ColorBar(brks = metric.breaks[['rpss']], cols = palette, vertical = FALSE, col_inf = colorunder, col_sup = colorsup) 
    dev.off()
  }
  if('crpss' %in% metrics){
    png(filename= paste0(fileout, "/scorecard_legend_crpss.png"), width=515, height=40)
    ColorBar(brks = metric.breaks[['crpss']], cols = palette, vertical = FALSE, col_inf = colorunder, col_sup = colorsup) 
    dev.off()
  }
  if('enssprerr' %in% metrics){
    png(filename= paste0(fileout, "/scorecard_legend_enssprerr.png"), width=515, height=40)
    ColorBar(brks = metric.breaks[['enssprerr']], cols = palette, vertical = FALSE, triangle_ends_scale = 1,  col_sup = colorsup)
    dev.off()
  }
  
  setwd(fileout)
  
  ## Paste all legends together
  for(m in metrics){
    if(m == metrics[1]){
      ## Add white space to the left of the first color bar legend
      system(paste0("convert ./scorecard_legend_", m, ".png -background white -splice 225x0 ./legend_scorecard.png"))
    } else {
      system(paste0("montage ./legend_scorecard.png ./scorecard_legend_",m,".png -tile 2x1 -geometry -4+10 ./legend_scorecard.png"))
    }
  }
  unlink('scorecard_legend*')
  
  ## Save html table as png
  my.file <- paste0(fileout, '/scorecard.png')
  try(save_kable(table.html, file = my.file), silent = TRUE)
  
  ## Add white space to the top of the scorecards, to be cut when adding legend:
  setwd(fileout)
  system(paste0("convert ./scorecard.png -background white -splice 0x20 ./scorecard.png"))
  
  ## Add the legends below the scorecard table
  system(paste0("montage ./scorecard.png ./legend_scorecard.png -tile 1x2 -geometry +0-10 ./scorecard.png"))
  
  unlink('legend_scorecard.png')
  
} ## close function  


  